@@ -8,7 +8,7 @@
 
 # Package name      : perl5
 # Source directory  : .
-# Configuration time: Fri Feb 12 13:48:44 EET 1999
+# Configuration time: Sat Feb 20 15:45:59 EET 1999
 # Configured by     : jhi
 # Target system     : osf1 alpha.hut.fi v4.0 878 alpha 
 
@@ -30,10 +30,10 @@ afs='false'
 alignbytes='8'
 ansi2knr=''
 aphostname=''
-apiversion='5.00554'
+apiversion='5.00555'
 ar='ar'
-archlib='/opt/perl/lib/5.00554/alpha-dec_osf-thread'
-archlibexp='/opt/perl/lib/5.00554/alpha-dec_osf-thread'
+archlib='/opt/perl/lib/5.00555/alpha-dec_osf-thread'
+archlibexp='/opt/perl/lib/5.00555/alpha-dec_osf-thread'
 archname64=''
 archname='alpha-dec_osf-thread'
 archobjs=''
@@ -51,11 +51,11 @@ cat='cat'
 cc='cc'
 cccdlflags=' '
 ccdlflags=' '
-ccflags='-pthread -std -D__LANGUAGE_C__'
+ccflags='-pthread -std -DLANGUAGE_C'
 ccsymbols='__LANGUAGE_C__=1 _LONGLONG=1 LANGUAGE_C=1 SYSTYPE_BSD=1'
 cf_by='jhi'
 cf_email='yourname@yourhost.yourplace.com'
-cf_time='Fri Feb 12 13:48:44 EET 1999'
+cf_time='Sat Feb 20 15:45:59 EET 1999'
 chgrp=''
 chmod=''
 chown=''
@@ -68,7 +68,7 @@ cpio=''
 cpp='cpp'
 cpp_stuff='42'
 cppccsymbols='__alpha=1 __osf__=1 __unix__=1 _SYSTYPE_BSD=1 unix=1'
-cppflags='-pthread -std -D__LANGUAGE_C__'
+cppflags='-pthread -std -DLANGUAGE_C'
 cpplast=''
 cppminus=''
 cpprun='/usr/bin/cpp'
@@ -160,6 +160,7 @@ d_gethent='define'
 d_gethname='define'
 d_gethostprotos='define'
 d_getlogin='define'
+d_getmntent='undef'
 d_getnbyaddr='define'
 d_getnbyname='define'
 d_getnent='define'
@@ -181,6 +182,7 @@ d_getservprotos='define'
 d_gettimeod='define'
 d_gnulibc='undef'
 d_grpasswd='define'
+d_hasmntopt='undef'
 d_htonl='define'
 d_index='undef'
 d_inetaton='define'
@@ -383,6 +385,7 @@ firstmakefile='makefile'
 flex=''
 fpostype='fpos_t'
 freetype='void'
+full_ar='/usr/bin/ar'
 full_csh='/usr/bin/csh'
 full_sed='/usr/bin/sed'
 gccversion=''
@@ -464,14 +467,14 @@ i_vfork='undef'
 ignore_versioned_solibs=''
 incpath=''
 inews=''
-installarchlib='/opt/perl/lib/5.00554/alpha-dec_osf-thread'
+installarchlib='/opt/perl/lib/5.00555/alpha-dec_osf-thread'
 installbin='/opt/perl/bin'
 installman1dir='/opt/perl/man/man1'
 installman3dir='/opt/perl/man/man3'
-installprivlib='/opt/perl/lib/5.00554'
+installprivlib='/opt/perl/lib/5.00555'
 installscript='/opt/perl/bin'
-installsitearch='/opt/perl/lib/site_perl/5.00554/alpha-dec_osf-thread'
-installsitelib='/opt/perl/lib/site_perl/5.00554'
+installsitearch='/opt/perl/lib/site_perl/5.00555/alpha-dec_osf-thread'
+installsitelib='/opt/perl/lib/site_perl/5.00555'
 installusrbinperl='define'
 intsize='4'
 known_extensions='B DB_File Data/Dumper Devel/Peek Fcntl GDBM_File IO IPC/SysV NDBM_File ODBM_File Opcode POSIX SDBM_File Socket Thread attrs re'
@@ -561,8 +564,8 @@ pmake=''
 pr=''
 prefix='/opt/perl'
 prefixexp='/opt/perl'
-privlib='/opt/perl/lib/5.00554'
-privlibexp='/opt/perl/lib/5.00554'
+privlib='/opt/perl/lib/5.00555'
+privlibexp='/opt/perl/lib/5.00555'
 prototype='define'
 ptrsize='8'
 randbits='48'
@@ -593,10 +596,10 @@ sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "EMT", "FPE"
 sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 6 6 16 20 23 23 23 29 48 '
 sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 6, 6, 16, 20, 23, 23, 23, 29, 48, 0'
 signal_t='void'
-sitearch='/opt/perl/lib/site_perl/5.00554/alpha-dec_osf-thread'
-sitearchexp='/opt/perl/lib/site_perl/5.00554/alpha-dec_osf-thread'
-sitelib='/opt/perl/lib/site_perl/5.00554'
-sitelibexp='/opt/perl/lib/site_perl/5.00554'
+sitearch='/opt/perl/lib/site_perl/5.00555/alpha-dec_osf-thread'
+sitearchexp='/opt/perl/lib/site_perl/5.00555/alpha-dec_osf-thread'
+sitelib='/opt/perl/lib/site_perl/5.00555'
+sitelibexp='/opt/perl/lib/site_perl/5.00555'
 sizetype='size_t'
 sleep=''
 smail=''
@@ -621,7 +624,7 @@ stdio_filbuf=''
 stdio_ptr='((fp)->_ptr)'
 strings='/usr/include/string.h'
 submit=''
-subversion='54'
+subversion='55'
 sysman='/usr/man/man1'
 tail=''
 tar=''
@@ -651,7 +654,7 @@ usethreads='define'
 usevfork='false'
 usrinc='/usr/include'
 uuname=''
-version='5.00554'
+version='5.00555'
 vi=''
 voidflags='15'
 xlibpth='/usr/lib/386 /lib/386'
@@ -671,8 +674,9 @@ config_arg7='-Dperladmin=yourname@yourhost.yourplace.com'
 config_arg8='-Dmydomain=.yourplace.com'
 config_arg9='-Dmyhostname=yourhost'
 config_arg10='-dE'
-PATCHLEVEL=5
-SUBVERSION=54
+PERL_REVISION=5
+PERL_VERSION=5
+PERL_SUBVERSION=55
 CONFIG=true
 # Variables propagated from previous config.sh file.
 pp_sys_cflags='ccflags="$ccflags -DNO_EFF_ONLY_OK"'
