@@ -133,7 +133,7 @@ do_aspawn (SV *really,SV **mark,SV **sp)
 {
     dTHR;
     int  rc;
-    char **a,*tmps,**argv;
+    char **a,*tmps,**argv; 
     STRLEN n_a;
 
     if (sp<=mark)
@@ -251,7 +251,6 @@ struct globinfo
     int    fd;
     char   *matches;
     size_t size;
-    fpos_t pos;
 };
 
 #define MAXOPENGLOBS 10
@@ -286,7 +285,6 @@ glob_handler (__FSEXT_Fnumber n,int *rv,va_list args)
             if ((gi=searchfd (-1)) == NULL)
                 break;
 
-            gi->pos=0;
             pattern=alloca (strlen (name+=13)+1);
             strcpy (pattern,name);
             if (!_USE_LFN)
@@ -333,10 +331,11 @@ glob_handler (__FSEXT_Fnumber n,int *rv,va_list args)
             if ((gi=searchfd (fd))==NULL)
                 break;
 
-            if (siz+gi->pos>gi->size)
-                siz=gi->size-gi->pos;
-            memcpy (buf,gi->pos+gi->matches,siz);
-            gi->pos+=siz;
+            ic=tell (fd);
+            if (siz+ic>=gi->size)
+                siz=gi->size-ic;
+            memcpy (buf,ic+gi->matches,siz);
+            lseek (fd,siz,1);
             *rv=siz;
             return 1;
         }
