@@ -3,7 +3,7 @@ package File::Spec::Functions;
 use File::Spec;
 use strict;
 
-use vars qw(@ISA @EXPORT @EXPORT_OK);
+use vars qw(@ISA @EXPORT);
 
 require Exporter;
 
@@ -14,16 +14,13 @@ require Exporter;
 	catdir
 	catfile
 	curdir
+	devnull
 	rootdir
+	tmpdir
 	updir
 	no_upwards
 	file_name_is_absolute
 	path
-);
-
-@EXPORT_OK = qw(
-	devnull
-	tmpdir
 	splitpath
 	splitdir
 	catpath
@@ -31,10 +28,9 @@ require Exporter;
 	rel2abs
 );
 
-foreach my $meth (@EXPORT, @EXPORT_OK) {
-    my $sub = File::Spec->can($meth);
+foreach my $meth (@EXPORT) {
     no strict 'refs';
-    *{$meth} = sub {&$sub('File::Spec', @_)};
+    *{$meth} = File::Spec->can($meth);
 }
 
 
@@ -68,17 +64,13 @@ The following functions are exported by default.
 	catdir
 	catfile
 	curdir
+	devnull
 	rootdir
+	tmpdir
 	updir
 	no_upwards
 	file_name_is_absolute
 	path
-
-
-The following functions are exported only by request.
-
-	devnull
-	tmpdir
 	splitpath
 	splitdir
 	catpath
