@@ -73,7 +73,6 @@ if ($docc) {
   open CONFIG, "< $config";
   while(<CONFIG>) {
     $debugging_enabled++ if /define\s+DEBUGGING/;
-    $hide_mymalloc++ if /define\s+EMBEDMYMALLOC/;
     $use_mymalloc++ if /define\s+MYMALLOC/;
   }
   
@@ -203,7 +202,7 @@ if ($use_mymalloc) {
   $fcns{'Perl_malloc'}++;
   $fcns{'Perl_calloc'}++;
   $fcns{'Perl_realloc'}++;
-  $fcns{'Perl_myfree'}++;
+  $fcns{'Perl_mfree'}++;
 }
 
 $used_expectation_enum = $used_opcode_enum = 0; # avoid warnings
@@ -262,18 +261,23 @@ LINE: while (<CPP>) {
 }
 close CPP;
 
-
+# This was:
 # Kluge to determine whether we need to add EMBED prefix to
 # symbols read from local list.  vmsreaddirversions() is a VMS-
 # specific function whose Perl_ prefix is added in vmsish.h
 # if EMBED is #defined.
-$embed = exists($fcns{'Perl_vmsreaddirversions'}) ? 'Perl_' : '';
+#
+# but now we always define EMBED, so it's not a big deal any more
 while (<DATA>) {
   next if /^#/;
   s/\s+#.*\n//;
   next if /^\s*$/;
   ($key,$array) = split('=',$_);
-  $key = "$embed$key";
+  if ($array eq 'vars') {
+      $key = "PL_$key";
+  } else {
+      $key = "Perl_$key";
+  }
   print "Adding $key to \%$array list\n" if $debug > 1;
   ${$array}{$key}++;
 }
